==> galileo-0.0.6-py3-none-any.whl: galileo/resources/models/healthcheck_response.py <==
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="HealthcheckResponse")


@_attrs_define
class HealthcheckResponse:
    """
    Attributes:
        api_version (str):
        message (str):
        version (str):
    """

    api_version: str
    message: str
    version: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        api_version = self.api_version

        message = self.message

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"api_version": api_version, "message": message, "version": version})

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        api_version = d.pop("api_version")

        message = d.pop("message")

        version = d.pop("version")

        healthcheck_response = cls(api_version=api_version, message=message, version=version)

        healthcheck_response.additional_properties = d
        return healthcheck_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> galileo-1.7.0-py3-none-any.whl: galileo/resources/models/healthcheck_response.py <==
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="HealthcheckResponse")


@_attrs_define
class HealthcheckResponse:
    """
    Attributes:
        api_version (str):
        message (str):
        version (str):
    """

    api_version: str
    message: str
    version: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        api_version = self.api_version

        message = self.message

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"api_version": api_version, "message": message, "version": version})

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        api_version = d.pop("api_version")

        message = d.pop("message")

        version = d.pop("version")

        healthcheck_response = cls(api_version=api_version, message=message, version=version)

        healthcheck_response.additional_properties = d
        return healthcheck_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
